@@ -6,7 +6,7 @@ use autodie;
 
 use 5.008;
 
-our $VERSION = '0.0.2';
+our $VERSION = '0.0.3';
 
 use IO::All qw/ io /;
 
@@ -56,7 +56,7 @@ Test::Data::Split - split data-driven tests into several test scripts.
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 SYNOPSIS
 
@@ -206,7 +206,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Test-Data-Split>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Data-Split>
 
 =item *
 
@@ -238,7 +238,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/Test-Data-Split>
+L<http://cpants.cpanauthors.org/dist/Test-Data-Split>
 
 =item *
 
@@ -269,7 +269,7 @@ L<http://deps.cpantesters.org/?module=Test::Data::Split>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-test-data-split at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Test-Data-Split>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Test-Data-Split>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
