@@ -3,7 +3,6 @@ package Test::Data::Split::Backend::Hash;
 use strict;
 use warnings;
 
-use List::MoreUtils qw/notall/;
 
 
 sub new
@@ -33,13 +32,7 @@ sub _init
 {
     my ($self, $args) = @_;
 
-    my $hash_ref = $self->get_hash;
-
-    if (notall { /\A[A-Za-z_\-0-9]{1,80}\z/ } keys (%$hash_ref))
-    {
-        die "Invalid key in hash reference. All keys must be alphanumeric plus underscores and dashes.";
-    }
-    $self->_hash($hash_ref);
+    $self->_hash(scalar ( $self->get_hash() ));
 
     return;
 }
@@ -48,7 +41,15 @@ sub list_ids
 {
     my ($self) = @_;
 
-    return [ sort { $a cmp $b } keys(%{$self->_hash}) ];
+    my @keys = keys(%{$self->_hash});
+
+    require List::MoreUtils;
+
+    if (List::MoreUtils::notall { /\A[A-Za-z_\-0-9]{1,80}\z/ } @keys)
+    {
+        die "Invalid key in hash reference. All keys must be alphanumeric plus underscores and dashes.";
+    }
+    return [ sort { $a cmp $b } @keys ];
 }
 
 sub lookup_data
@@ -70,7 +71,7 @@ Test::Data::Split::Backend::Hash - hash backend.
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 SYNOPSIS
 
@@ -181,7 +182,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Test-Data-Split>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Data-Split>
 
 =item *
 
@@ -213,7 +214,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/Test-Data-Split>
+L<http://cpants.cpanauthors.org/dist/Test-Data-Split>
 
 =item *
 
@@ -244,7 +245,7 @@ L<http://deps.cpantesters.org/?module=Test::Data::Split>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-test-data-split at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Test-Data-Split>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Test-Data-Split>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
